@@ -12,12 +12,14 @@ class PLUTO(metaclass=GeolUnits):
 
     LEGEND = {
         0: 'No data',
+        64: 'Washboard units',
         128: 'Sputnik Planitia',
         255: 'Bladed units',
     }
 
     CMAP = UnitsColormap({
         0: '#00000000',  # No-data
+        64: '#00ff00',  # Washboard units
         128: '#0000ff',  # Sputnik Planitia
         255: '#ff0000',  # Bladed unit
     }, name='pluto_geol')
